@@ -129,7 +129,7 @@ def _contents_same(contents, file_size):
                 return Different
 
 
-def _normalize(contents, ignore_blank_lines, regexes = ()):
+def _normalize(contents, ignore_blank_lines, regexes=()):
     contents = (bytes(c) for c in contents)
     # For probable text files, discard newline differences to match
     if ignore_blank_lines:
@@ -392,19 +392,10 @@ class DirDiff(MeldDoc, Component):
         self.model.on_style_updated(self.widget)
 
         self.do_to_others_lock = False
-        self.focus_in_events = []
-        self.focus_out_events = []
         for treeview in self.treeview:
-            handler_id = treeview.connect(
-                "focus-in-event", self.on_treeview_focus_in_event)
-            self.focus_in_events.append(handler_id)
-            handler_id = treeview.connect(
-                "focus-out-event", self.on_treeview_focus_out_event)
-            self.focus_out_events.append(handler_id)
             treeview.set_search_equal_func(tree.treeview_search_cb, None)
         self.force_cursor_recalculate = False
         self.current_path, self.prev_path, self.next_path = None, None, None
-        self.on_treeview_focus_out_event(None, None)
         self.focus_pane = None
         self.row_expansions = set()
 
@@ -532,8 +523,6 @@ class DirDiff(MeldDoc, Component):
                                     Gtk.get_current_event_time())
 
     def _cleanup_filter_menu_button(self, ui):
-        if self.popup_deactivate_id:
-            self.popup_menu.disconnect(self.popup_deactivate_id)
         if self.custom_merge_id:
             ui.remove_ui(self.custom_merge_id)
         if self.filter_actiongroup in ui.get_action_groups():
@@ -544,8 +533,6 @@ class DirDiff(MeldDoc, Component):
         self.custom_merge_id = ui.new_merge_id()
         for x in self.filter_ui:
             ui.add_ui(self.custom_merge_id, *x)
-        self.popup_deactivate_id = self.popup_menu.connect(
-            "deactivate", self.on_popup_deactivate_event)
         self.custom_popup = ui.get_widget("/CustomPopup")
         self.filter_menu_button = ui.get_widget(
             "/Toolbar/FilterActions/CustomFilterMenu")
@@ -1133,7 +1120,9 @@ class DirDiff(MeldDoc, Component):
                 # We can skip recalculation if the new cursor is between
                 # the previous/next bounds, and we weren't on a changed row
                 state = self.model.get_state(old_cursor, 0)
-                if state not in (tree.STATE_NORMAL, tree.STATE_NOCHANGE, tree.STATE_EMPTY):
+                if state not in (
+                        tree.STATE_NORMAL, tree.STATE_NOCHANGE,
+                        tree.STATE_EMPTY):
                     skip = False
                 else:
                     if self.prev_path is None and self.next_path is None:
@@ -1208,28 +1197,12 @@ class DirDiff(MeldDoc, Component):
         self._do_to_others(view, self.treeview, "collapse_row", (path,))
         self._update_diffmaps()
 
-    def on_popup_deactivate_event(self, popup):
-        for (treeview, inid, outid) in zip(
-                self.treeview, self.focus_in_events, self.focus_out_events):
-            treeview.handler_unblock(inid)
-            treeview.handler_unblock(outid)
-
     def on_treeview_focus_in_event(self, tree, event):
         self.focus_pane = tree
         pane = self.treeview.index(tree)
         self.on_treeview_selection_changed(tree.get_selection(), pane)
         tree.emit("cursor-changed")
 
-    def on_treeview_focus_out_event(self, tree, event):
-        for action in ("DirCompare", "DirCopyLeft", "DirCopyRight",
-                       "DirDelete", "Hide"):
-            self.actiongroup.get_action(action).set_sensitive(False)
-        try:
-            self.main_actiongroup.get_action("OpenExternal").set_sensitive(
-                False)
-        except AttributeError:
-            pass
-
     def run_diff_from_iter(self, it):
         row_paths = self.model.value_paths(it)
         gfiles = [Gio.File.new_for_path(p)
@@ -1471,10 +1444,6 @@ class DirDiff(MeldDoc, Component):
         return different
 
     def popup_in_pane(self, pane, event):
-        for (treeview, inid, outid) in zip(
-                self.treeview, self.focus_in_events, self.focus_out_events):
-            treeview.handler_block(inid)
-            treeview.handler_block(outid)
         self.actiongroup.get_action("DirCopyLeft").set_sensitive(pane > 0)
         self.actiongroup.get_action("DirCopyRight").set_sensitive(
             pane + 1 < self.num_panes)
