@@ -40,7 +40,7 @@ from meld.windowstate import SavedWindowState
 class MeldWindow(Component):
 
     def __init__(self):
-        Component.__init__(self, "meldapp.ui", "meldapp")
+        super().__init__("meldapp.ui", "meldapp")
         self.widget.set_name("meldapp")
 
         actions = (
@@ -183,14 +183,19 @@ class MeldWindow(Component):
         interface_settings.bind('toolbar-style', self.toolbar, 'toolbar-style',
                                 Gio.SettingsBindFlags.DEFAULT)
 
-        # Add alternate keybindings for Prev/Next Change
-        accels = self.ui.get_accel_group()
-        (keyval, mask) = Gtk.accelerator_parse("<Primary>D")
-        accels.connect(keyval, mask, 0, self.on_menu_edit_down_activate)
-        (keyval, mask) = Gtk.accelerator_parse("<Primary>E")
-        accels.connect(keyval, mask, 0, self.on_menu_edit_up_activate)
-        (keyval, mask) = Gtk.accelerator_parse("F5")
-        accels.connect(keyval, mask, 0, self.on_menu_refresh_activate)
+        # Alternate keybindings for a few commands.
+        extra_accels = (
+            ("<Primary>D", self.on_menu_edit_down_activate),
+            ("<Primary>E", self.on_menu_edit_up_activate),
+            ("<Alt>KP_Down", self.on_menu_edit_down_activate),
+            ("<Alt>KP_Up", self.on_menu_edit_up_activate),
+            ("F5", self.on_menu_refresh_activate),
+        )
+
+        accel_group = self.ui.get_accel_group()
+        for accel, callback in extra_accels:
+            keyval, mask = Gtk.accelerator_parse(accel)
+            accel_group.connect(keyval, mask, 0, callback)
 
         # Initialise sensitivity for important actions
         self.actiongroup.get_action("Stop").set_sensitive(False)
@@ -269,10 +274,11 @@ class MeldWindow(Component):
         # Let the rest of the stack know about this event
         return False
 
-    def on_widget_drag_data_received(self, wid, context, x, y, selection_data,
-                                     info, time):
-        if len(selection_data.get_files()) != 0:
-            self.open_paths(selection_data.get_files())
+    def on_widget_drag_data_received(
+            self, wid, context, x, y, selection_data, info, time):
+        uris = selection_data.get_uris()
+        if uris:
+            self.open_paths([Gio.File.new_for_uri(uri) for uri in uris])
             return True
 
     def on_idle(self):
@@ -689,7 +695,7 @@ class MeldWindow(Component):
             if isinstance(page, MeldDoc):
                 return page
 
-        class DummyDoc(object):
+        class DummyDoc:
             def __getattr__(self, a):
                 return lambda *x: None
         return DummyDoc()
